@@ -1,5 +1,8 @@
 
-#include	<gobject/gmarshal.h>
+#ifndef ___wnck_marshal_MARSHAL_H__
+#define ___wnck_marshal_MARSHAL_H__
+
+#include	<glib-object.h>
 
 G_BEGIN_DECLS
 
@@ -13,3 +16,5 @@ extern void _wnck_marshal_VOID__FLAGS_FLAGS (GClosure     *closure,
 
 G_END_DECLS
 
+#endif /* ___wnck_marshal_MARSHAL_H__ */
+
